@@ -8,7 +8,8 @@ import sys
 import os
 from optparse import OptionParser
 
-from html5lib import html5parser, liberalxmlparser
+from html5lib import html5parser, sanitizer
+from html5lib.tokenizer import HTMLTokenizer
 from html5lib import treebuilders, serializer, treewalkers
 from html5lib import constants
 
@@ -42,10 +43,13 @@ def parse():
 
     treebuilder = treebuilders.getTreeBuilder(opts.treebuilder)
 
-    if opts.xml:
-        p = liberalxmlparser.XHTMLParser(tree=treebuilder)
+    if opts.sanitize:
+        tokenizer = sanitizer.HTMLSanitizer
     else:
-        p = html5parser.HTMLParser(tree=treebuilder)
+        tokenizer = HTMLTokenizer
+
+
+    p = html5parser.HTMLParser(tree=treebuilder, tokenizer=tokenizer)
 
     if opts.fragment:
         parseMethod = p.parseFragment
@@ -53,6 +57,7 @@ def parse():
         parseMethod = p.parse
 
     if opts.profile:
+        #XXX should import cProfile instead and use that
         import hotshot
         import hotshot.stats
         prof = hotshot.Profile('stats.prof')
@@ -70,7 +75,7 @@ def parse():
         t1 = time.time()
         printOutput(p, document, opts)
         t2 = time.time()
-        print "\n\nRun took: %fs (plus %fs to print the output)"%(t1-t0, t2-t1)
+        sys.stderr.write("\n\nRun took: %fs (plus %fs to print the output)"%(t1-t0, t2-t1))
     else:
         document = parseMethod(f, encoding=encoding)
         printOutput(p, document, opts)
